import { Observable } from 'rxjs';
import { database } from 'firebase';
export interface ExtendedDataSnapshot extends database.DataSnapshot {
    prevKey: string;
}
export declare class DataSnapshotObservable<T> extends Observable<ExtendedDataSnapshot> {
    exists(): Observable<boolean>;
    children<C>(): Observable<DataSnapshotObservable<C>>;
    /**
     * This operator takes the result of .val() for all children of the snapshot and emits
     * them as an array.
     * Contents of source snapshot:
     * ```
     * {
     *  childA: { prop: 'Hello' },
     *  childB: { prop: 'World!' },
     * }
     * ```
     * Result of operator:
     * ```
     * [
     *  { prop: 'Hello' },
     *  { prop: 'World!' },
     * ]
     * ```
     * @returns {Observable<C[]>}
     */
    toValArray<C>(): Observable<C[]>;
    key(): Observable<string>;
    /**
     * When listening to events such as {@link Event.ChildMoved} the snapshot includes
     * the key of the child before this snapshots one. This operator maps to this key.
     * @returns {Observable<string>}
     */
    prevKey(): Observable<string>;
    val<T>(): Observable<T>;
    getPriority(): Observable<number | string>;
    exportVal(): Observable<any>;
    hasChild(path: string): Observable<boolean>;
    hasChildren(): Observable<boolean>;
    numChildren(): Observable<number>;
    child<C>(path: string): DataSnapshotObservable<C>;
}
